@@ -1,11 +1,11 @@
 package MyAttrs;
-our $VERSION = '0.02';
-
 use MooseX::Attributes::Curried (
     has_str => {
+        is  => 'bare',
         isa => 'Str',
     },
     has_int => {
+        is      => 'bare',
         isa     => 'Int',
         default => 0,
     },
